summarylogtreecommitdiffstats
diff options
context:
space:
mode:
authorUffe Jakobsen2024-04-09 10:55:06 +0200
committerUffe Jakobsen2024-04-09 10:55:06 +0200
commit598c5db12715a2f74e122cae6bffd2aab4bbce98 (patch)
treeff7b8f3ec5bf0fa612194ce70551227ae5a9ef2d
parent36d901c8c48eb4e32c8d89218253d76bda462b95 (diff)
downloadaur-598c5db12715a2f74e122cae6bffd2aab4bbce98.tar.gz
Update patch
-rw-r--r--codelite-fsw-symlink.patch48
1 files changed, 24 insertions, 24 deletions
diff --git a/codelite-fsw-symlink.patch b/codelite-fsw-symlink.patch
index a671344e4921..50b518c3aef1 100644
--- a/codelite-fsw-symlink.patch
+++ b/codelite-fsw-symlink.patch
@@ -13,7 +13,7 @@ index f0f48e2d3..f4019cf5f 100644
set(ADDITIONAL_LIBRARIES "")
diff --git LiteEditor/mainbook.cpp LiteEditor/mainbook.cpp
-index f1c7e9ca7..91a9b9a45 100644
+index fd9c216f8..88b913b10 100644
--- LiteEditor/mainbook.cpp
+++ LiteEditor/mainbook.cpp
-@@ -417,7 +417,7 @@ int MainBook::FindEditorIndexByFullPath(const wxString& fullpath)
+@@ -418,7 +418,7 @@ int MainBook::FindEditorIndexByFullPath(const wxString& fullpath)
{
#ifdef __WXGTK__
// On gtk either fileName or the editor filepath (or both) may be (or their paths contain) symlinks
@@ -115,7 +115,7 @@ index f1c7e9ca7..91a9b9a45 100644
#endif
for (size_t i = 0; i < m_book->GetPageCount(); ++i) {
-@@ -451,7 +451,7 @@ int MainBook::FindEditorIndexByFullPath(const wxString& fullpath)
+@@ -452,7 +452,7 @@ int MainBook::FindEditorIndexByFullPath(const wxString& fullpath)
#if defined(__WXGTK__)
// Try again, dereferencing the editor fpath
@@ -124,7 +124,7 @@ index f1c7e9ca7..91a9b9a45 100644
if (editorDest.Cmp(fullpath) == 0 || editorDest.Cmp(fileNameDest) == 0) {
return i;
}
-@@ -580,6 +580,13 @@ clEditor* MainBook::OpenFile(const wxString& file_name, const wxString& projectN
+@@ -581,6 +581,13 @@ clEditor* MainBook::OpenFile(const wxString& file_name, const wxString& projectN
int bmp /*= wxNullBitmap*/, const wxString& tooltip /* wxEmptyString */)
{
wxFileName fileName(CLRealPath(file_name));
@@ -138,7 +138,7 @@ index f1c7e9ca7..91a9b9a45 100644
fileName.MakeAbsolute();
#ifdef __WXMSW__
-@@ -1723,7 +1730,7 @@ WelcomePage* MainBook::GetWelcomePage(bool createIfMissing)
+@@ -1724,7 +1731,7 @@ WelcomePage* MainBook::GetWelcomePage(bool createIfMissing)
clEditor* MainBook::OpenFileAsync(const wxString& file_name, std::function<void(IEditor*)>&& callback)
{
@@ -147,7 +147,7 @@ index f1c7e9ca7..91a9b9a45 100644
auto editor = FindEditor(real_path);
if (editor) {
push_callback(std::move(callback), real_path);
-@@ -1734,7 +1741,7 @@ clEditor* MainBook::OpenFileAsync(const wxString& file_name, std::function<void(
+@@ -1735,7 +1742,7 @@ clEditor* MainBook::OpenFileAsync(const wxString& file_name, std::function<void(
m_book->SetSelection(index);
}
} else {
@@ -156,7 +156,7 @@ index f1c7e9ca7..91a9b9a45 100644
if (editor) {
push_callback(std::move(callback), real_path);
}
-@@ -1793,11 +1800,12 @@ void MainBook::OnIdle(wxIdleEvent& event)
+@@ -1800,11 +1807,12 @@ void MainBook::OnIdle(wxIdleEvent& event)
auto editor = GetActiveEditor();
CHECK_PTR_RET(editor);
diff --git CodeLite/clFilesCollector.cpp CodeLite/clFilesCollector.cpp
-index 38b1f619a..9a4bbd6e8 100644
+index 9ac968545..1bc295017 100644
--- CodeLite/clFilesCollector.cpp
+++ CodeLite/clFilesCollector.cpp
@@ -2,6 +2,7 @@
@@ -23,8 +23,8 @@ index 38b1f619a..9a4bbd6e8 100644
+#include "globals.h"
#include <queue>
- #include <vector>
-@@ -9,6 +10,8 @@
+ #include <unordered_set>
+@@ -10,6 +11,8 @@
#include <wx/filename.h>
#include <wx/tokenzr.h>
@@ -33,7 +33,7 @@ index 38b1f619a..9a4bbd6e8 100644
clFilesScanner::clFilesScanner() {}
clFilesScanner::~clFilesScanner() {}
-@@ -105,19 +108,19 @@ size_t clFilesScanner::Scan(const wxString& rootFolder, std::vector<wxString>& f
+@@ -110,19 +113,19 @@ size_t clFilesScanner::Scan(const wxString& rootFolder, std::vector<wxString>& f
filename.MakeLower();
#endif
bool isDirectory = wxFileName::DirExists(fullpath);
@@ -50,14 +50,14 @@ index 38b1f619a..9a4bbd6e8 100644
+ (excludeFolders.count(my_CLRealPath(fullpath))
#endif
|| IsRelPathContainedInSpec(rootFolder, fullpath, excludeFolders)));
- if(isDirectory && !isExcludeDir) {
+ if (isDirectory && !isExcludeDir) {
// Traverse into this folder
- wxString realPath = FileUtils::RealPath(fullpath);
+ wxString realPath = my_CLRealPath(fullpath);
- if(Visited.insert(realPath).second) {
+ if (Visited.insert(realPath).second) {
Q.push(fullpath);
}
-@@ -148,8 +151,8 @@ size_t clFilesScanner::Scan(const wxString& rootFolder, const wxString& filespec
+@@ -153,8 +156,8 @@ size_t clFilesScanner::Scan(const wxString& rootFolder, const wxString& filespec
std::queue<wxString> Q;
std::unordered_set<wxString> Visited;
@@ -67,22 +67,22 @@ index 38b1f619a..9a4bbd6e8 100644
+ Visited.insert(my_CLRealPath(rootFolder));
size_t nCount = 0;
- while(!Q.empty()) {
-@@ -169,11 +172,11 @@ size_t clFilesScanner::Scan(const wxString& rootFolder, const wxString& filespec
+ while (!Q.empty()) {
+@@ -174,11 +177,11 @@ size_t clFilesScanner::Scan(const wxString& rootFolder, const wxString& filespec
fullpath << dir.GetNameWithSep() << filename;
bool isDirectory = wxFileName::DirExists(fullpath);
bool isFile = !isDirectory;
- // Use FileUtils::RealPath() here to cope with symlinks on Linux
+ // Use CLRealPath() here to cope with symlinks on Linux
- if(isDirectory /* a folder */ &&
- !FileUtils::WildMatch(excludeFoldersSpecArr, filename) /* does not match the exclude folder spec */) {
+ if (isDirectory /* a folder */ &&
+ !FileUtils::WildMatch(excludeFoldersSpecArr, filename) /* does not match the exclude folder spec */) {
// Traverse into this folder
- wxString real_path = FileUtils::RealPath(fullpath);
+ wxString real_path = my_CLRealPath(fullpath);
- if(Visited.count(real_path) == 0) {
+ if (Visited.count(real_path) == 0) {
Visited.insert(real_path);
Q.push(fullpath);
-@@ -254,8 +257,8 @@ void clFilesScanner::ScanWithCallbacks(const wxString& rootFolder, std::function
+@@ -259,8 +262,8 @@ void clFilesScanner::ScanWithCallbacks(const wxString& rootFolder, std::function
std::vector<wxString> Q;
std::unordered_set<wxString> Visited;
@@ -91,22 +91,22 @@ index 38b1f619a..9a4bbd6e8 100644
+ Q.push_back(my_CLRealPath(rootFolder));
+ Visited.insert(my_CLRealPath(rootFolder));
- while(!Q.empty()) {
+ while (!Q.empty()) {
wxString dirpath = Q.front();
-@@ -294,7 +297,7 @@ void clFilesScanner::ScanWithCallbacks(const wxString& rootFolder, std::function
+@@ -299,7 +302,7 @@ void clFilesScanner::ScanWithCallbacks(const wxString& rootFolder, std::function
- if(on_folder_cb && on_folder_cb(fullpath)) {
+ if (on_folder_cb && on_folder_cb(fullpath)) {
// Traverse into this folder
- wxString real_path = FileUtils::RealPath(fullpath);
+ wxString real_path = my_CLRealPath(fullpath);
- if(Visited.insert(real_path).second) {
+ if (Visited.insert(real_path).second) {
Q.push_back(fullpath);
}